@@ -71,7 +71,7 @@ Print.prototype.beginEvent = function() {
     this.terminate();
 };
 
-Print.prototype.createPrinter = function(pdfFile, printerName) {
+Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
     var printer = undefined;
 
     // print directly to given printer or default printer:
@@ -86,12 +86,26 @@ Print.prototype.createPrinter = function(pdfFile, printerName) {
         }
     }
 
+    if (isNull(pdfVersion)) {
+        pdfVersion = "1.4";
+    }
+
     if (isNull(printer)) {
         // create printer on the fly:
         printer = new QPrinter(QPrinter.HighResolution);
 
         if (isString(pdfFile)) {
             printer.setOutputFormat(QPrinter.PdfFormat);
+            if (pdfVersion.toLowerCase()==="a-1b" || pdfVersion.toLowerCase()==="a1b" || pdfVersion.toLowerCase()==="a") {
+                printer.setPdfVersion(1 /*QPagedPaintDevice.PdfVersion_A1b*/);
+            }
+            else if (pdfVersion.toLowerCase()==="1.6") {
+                printer.setPdfVersion(2 /*QPagedPaintDevice.PdfVersion_1_6*/);
+            }
+            else {
+                printer.setPdfVersion(0 /*QPagedPaintDevice.PdfVersion_1_4*/);
+            }
+
             printer.setOutputFileName(pdfFile);
         }
     }
@@ -179,8 +193,14 @@ Print.prototype.createPrinter = function(pdfFile, printerName) {
  * \param printerName Name of printer to print to or "" for default printer.
  * \param printer QPrinter object or undefined to create on the fly.
  */
-Print.prototype.print = function(pdfFile, printerName) {
-    var printer = this.createPrinter(pdfFile, printerName);
+Print.prototype.print = function(pdfFile, printerName, pdfVersion) {
+    // make sure selected entities are not printed with selection color:
+    var di = EAction.getDocumentInterface();
+    if (!isNull(di)) {
+        di.deselectAll();
+    }
+
+    var printer = this.createPrinter(pdfFile, printerName, pdfVersion);
     if (isNull(printer)) {
         qWarning("Print.prototype.print: no printer created");
         return false;
@@ -207,13 +227,15 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
 
     // set background color of view to match printing preference:
     var bgColor = this.view.getBackgroundColor();
+    var scale = Print.getScale(this.document);
 
     this.view.setBackgroundColor(Print.getBackgroundColor(this.document));
     this.view.setPrinting(true);
     // 20191007: avoid invisible lines in prints and PDF output:
     var minLineweightSet = false;
     if (this.view.getMinimumLineweight()<RS.PointTolerance) {
-        this.view.setMinimumLineweight(0.01);
+        // no minimum lineweight defined: force minimum lineweight of 0.01mm for printing:
+        this.view.setMinimumLineweight(RUnit.convert(0.01/scale, RS.Millimeter, this.document.getUnit()));
         minLineweightSet = true;
     }
 
@@ -241,12 +263,19 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     );
 
     // printer calibration:
-    printerFactor.x *= RSettings.getDoubleValue(printer.printerName() + "/FactorX", 1.0);
-    printerFactor.y *= RSettings.getDoubleValue(printer.printerName() + "/FactorY", 1.0);
+    var printerName = printer.printerName();
+    if (printerName.length===0) {
+        if (printer.outputFileName().length!==0) {
+            // PDF output:
+            printerName = "PDF";
+        }
+    }
+
+    printerFactor.x *= RSettings.getDoubleValue(printerName + "/FactorX", 1.0);
+    printerFactor.y *= RSettings.getDoubleValue(printerName + "/FactorY", 1.0);
 
     this.view.setPrintPointSize(new RVector(1.0/printerFactor.x, 1.0/printerFactor.y));
 
-    var scale = Print.getScale(this.document);
     var offset = Print.getOffset(this.document);
 
     var previousPixelSizeHint = this.scene.getPixelSizeHint();
@@ -398,7 +427,7 @@ Print.autoFitDrawing = function(di) {
     var document = di.getDocument();
     // drawing bounding box in drawing units:
     var bBox = document.getBoundingBox(true, true);
-    qDebug("bb: ", bBox);
+    //qDebug("bb: ", bBox);
     Print.autoFitBox(di, bBox);
     Print.centerBox(di, bBox);
 };
@@ -444,7 +473,7 @@ Print.autoFitBox = function(di, bBox) {
         f = 1.0;
     }
 
-    qDebug("f:", f);
+    //qDebug("f:", f);
 
     Print.setScale(di, f);
     Print.centerBox(di, bBox);
