@@ -314,11 +314,16 @@ Scale.prototype.getOperation = function(preview) {
 };
 
 Scale.prototype.transformArc = function(shape, sv) {
-    if (isCircleShape(shape)) {
-        shape = ShapeAlgorithms.circleToArc(shape, 0.0);
+    var s = shape;
+    if (isFunction(shape.data)) {
+        s = shape.data();
     }
 
-    return RShape.scaleArc(shape, sv, this.focusPoint);
+    if (isCircleShape(s)) {
+        s = ShapeAlgorithms.circleToArc(s, 0.0);
+    }
+
+    return RShape.scaleArc(s, sv, this.focusPoint);
 };
 
 /**
@@ -362,11 +367,11 @@ Scale.prototype.transform = function(entity, k, op, preview, flags) {
     if (isHatchEntity(entity)) {
         //debugger;
         var data = entity.getData();
-        var newHatchData = data.copy();
+        var newHatchData = new RHatchData();
         newHatchData.setDocument(data.getDocument());
         newHatchData.copyAttributesFrom(data);
 
-        newHatchData.clearBoundary();
+        //newHatchData.clearBoundary();
 
         for (var i=0; i<entity.getLoopCount(); i++) {
             newHatchData.newLoop();
@@ -386,6 +391,12 @@ Scale.prototype.transform = function(entity, k, op, preview, flags) {
                 }
             }
         }
+        newHatchData.setSolid(entity.isSolid());
+        newHatchData.setPatternName(entity.getPatternName());
+        newHatchData.setScale(entity.getScale());
+        newHatchData.setAngle(entity.getAngle());
+        newHatchData.setOriginPoint(entity.getOriginPoint());
+
         entity.setData(newHatchData);
         op.addObject(entity, flags);
         return;
